#
# spec file for package python-arf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-arf
Version:        2.6.7
Release:        2.1
# Note: I know that "advertisement" words are frowned on, but in this case
# the package name is an acronym so "advanced" needs to stay in
Summary:        Advanced Recording Format for physiology and behavior
License:        GPL-2.0-only
URL:            https://github.com/melizalab/arf
Source:         https://files.pythonhosted.org/packages/source/a/arf/arf-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-h5py >= 2.8
Conflicts:      (python-h5py >= 3.3 with python-h5py < 3.4)
BuildArch:      noarch
# Leap 15.4 h5py-3.1 misses the cached-property requirement for python36
%if 0%{suse_version} < 1550
BuildRequires:  %{python_module cached-property}
Requires:       python-cached-property
%endif
# SECTION test requirements
BuildRequires:  %{python_module h5py >= 2.8 with (%python-h5py < 3.3 or %python-h5py >= 3.4)}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
The Advanced Recording Format ARF is an open standard for storing
data from neuronal, acoustic, and behavioral experiments in a
portable, high-performance, archival format. The goal is to enable
labs to share data and tools, and to allow data to be accessed and
analyzed for many years in the future.

ARF is built on the the HDF5 format, and all arf files are accessible
through standard HDF5 tools, including interfaces to HDF5 written for
other languages (e.g. MATLAB, Python, etc). ARF comprises a set of
specifications on how different kinds of data are stored.

%prep
%autosetup -p1 -n arf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license COPYING
%{python_sitelib}/arf.py
%pycache_only %{python_sitelib}/__pycache__/arf*.pyc
%{python_sitelib}/arf-%{version}.dist-info

%changelog
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.6:
  * Added CI testing for newer versions of Python and other
    platforms. Added type annotations.
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6.4:
  * no upstream changelog available
- drop h5py-fixup.patch, arf-pr10-h5py-open.patch (upstream)
* Tue Jul 12 2022 Markéta Machová <mmachova@suse.com>
- Add h5py-fixup.patch -- gh#melizalab/arf#12
* Sun Apr  3 2022 Ben Greiner <code@bnavigator.de>
- Add arf-pr10-h5py-open.patch -- gh#melizalab/arf#10
* Wed Jul  7 2021 Matej Cepl <mcepl@suse.com>
- Skip failing test test01_creation_iter (gh#melizalab/arf#8).
* Fri Apr  9 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.6.1
  * no release notes
- Requirement bumps (definitions from Readme, setup.py,
  requirements.txt are inconsistent)
- Skip python36 build: No NumPy 1.20 for Python 3.6
* Mon Oct  5 2020 Matej Cepl <mcepl@suse.com>
- Update to 2.6.0:
  - Remove our denose.patch, because it was included in the
    upstream tarball.
* Wed Jul 22 2020 Matej Cepl <mcepl@suse.com>
- Add denose.patch which eliminates dependency on nose
  (gh#melizalab/arf#7).
* Thu Nov 21 2019 Todd R <toddrme2178@gmail.com>
- initial version
